@@ -318,12 +318,25 @@ class MeldWindow(gnomeglade.Component):
         self.actiongroup.get_action("MoveTabPrev").set_sensitive(have_prev_tab)
         self.actiongroup.get_action("MoveTabNext").set_sensitive(have_next_tab)
 
-        have_focus = current_page != -1
-        self.actiongroup.get_action("Close").set_sensitive(have_focus)
-        self.actiongroup.get_action("Refresh").set_sensitive(have_focus)
-        if not have_focus:
-            self.actiongroup.get_action("PrevChange").set_sensitive(False)
-            self.actiongroup.get_action("NextChange").set_sensitive(False)
+        if current_page != -1:
+            page = self.notebook.get_nth_page(
+                current_page).get_data("pyobject")
+        else:
+            page = None
+
+        self.actiongroup.get_action("Close").set_sensitive(bool(page))
+        if not isinstance(page, melddoc.MeldDoc):
+            for action in ("PrevChange", "NextChange", "Cut", "Copy", "Paste",
+                           "Find", "FindNext", "FindPrevious", "Replace",
+                           "Refresh"):
+                self.actiongroup.get_action(action).set_sensitive(False)
+        else:
+            for action in ("Find", "Refresh"):
+                self.actiongroup.get_action(action).set_sensitive(True)
+            is_filediff = isinstance(page, filediff.FileDiff)
+            for action in ("Cut", "Copy", "Paste", "FindNext", "FindPrevious",
+                           "Replace"):
+                self.actiongroup.get_action(action).set_sensitive(is_filediff)
 
     def on_switch_page(self, notebook, page, which):
         oldidx = notebook.get_current_page()
@@ -768,7 +781,7 @@ class MeldWindow(gnomeglade.Component):
         doc.set_location(path)
         doc.connect("create-diff", lambda obj, arg, kwargs:
                     self.append_diff(arg, **kwargs))
-        doc.run_diff([path])
+        doc.run_diff(path)
 
     def open_paths(self, paths, auto_compare=False, auto_merge=False):
         tab = None
