@@ -1,7 +1,7 @@
 
-import historyentry
-import msgarea
-import statusbar
+from . import historyentry
+from . import msgarea
+from . import statusbar
 import meld.linkmap
 import meld.diffmap
 import meld.util.sourceviewer
