@@ -13,10 +13,13 @@
 
 ### You should have received a copy of the GNU General Public License
 ### along with this program; if not, write to the Free Software
-### Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+### Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+### USA.
+
+import logging
+import re
 
 import gtk
-import re
 
 
 # FIXME: duplicate defn in bin/meld
@@ -42,9 +45,8 @@ class Component(object):
         """
         self.builder = gtk.Builder()
         self.builder.set_translation_domain(locale_domain)
-        if extra:
-            self.builder.add_objects_from_file(filename, extra)
-        self.builder.add_objects_from_file(filename, [root])
+        objects = [root] + extra if extra else [root]
+        self.builder.add_objects_from_file(filename, objects)
         self.builder.connect_signals(self)
         self.widget = getattr(self, root)
         self.widget.set_data("pyobject", self)
@@ -84,16 +86,17 @@ class Component(object):
 handler_re = re.compile(r'^(on|after)_(.*)__(.*)$')
 
 def connect_signal_handlers(obj):
+    log = logging.getLogger(__name__)
     for attr in dir(obj):
         match = handler_re.match(attr)
         if match:
             when, widgetname, signal = match.groups()
             method = getattr(obj, attr)
-            assert callable(method)
+            assert hasattr(method, '__call__')
             try:
                 widget = getattr(obj, widgetname)
             except AttributeError:
-                print "Widget '%s' not found in %s" % (widgetname, obj)
+                log.warning("Widget '%s' not found in %s", widgetname, obj)
                 continue
             if not isinstance(widget,list):
                 widget = [widget]
@@ -104,13 +107,13 @@ def connect_signal_handlers(obj):
                     elif when == 'after':
                         w.connect_after(signal, method)
                 except TypeError as e:
-                    print e, "in", obj, attr
+                    log.warning("%s in %s %s", e, obj, attr)
         elif attr.startswith('on_') or attr.startswith('after_'):
             continue # don't warn until all old code updated
             # Warn about some possible typos like separating
             # widget and signal name with _ instead of __.
-            print ('Warning: attribute %r not connected'
-                   ' as a signal handler' % (attr,))
+            log.warning("Warning: attribute %r not connected as a signal "
+                        "handler", attr)
 
 
-import gladesupport
+from . import gladesupport
