@@ -99,8 +99,6 @@ class File(Entry):
 
 class Vc(object):
 
-    PATCH_STRIP_NUM = 0
-    PATCH_INDEX_RE = ''
     VC_DIR = None
     VC_ROOT_WALK = True
     VC_METADATA = None
@@ -126,9 +124,6 @@ class Vc(object):
     def commit_command(self, message):
         raise NotImplementedError()
 
-    def diff_command(self):
-        raise NotImplementedError()
-
     def update_command(self):
         raise NotImplementedError()
 
@@ -144,9 +139,6 @@ class Vc(object):
     def resolved_command(self):
         raise NotImplementedError()
 
-    def patch_command(self, workdir):
-        return ["patch", "-p%i" % self.PATCH_STRIP_NUM, "-R", "-d", workdir]
-
     # Prototyping VC interface version 2
 
     def get_files_to_commit(self, paths):
@@ -163,6 +155,15 @@ class Vc(object):
 
     def revert(self, runner, files):
         raise NotImplementedError()
+    
+    def get_commits_to_push_summary(self):
+        raise NotImplementedError()
+
+    def remove(self, runner, files):
+        raise NotImplementedError()
+
+    def resolve(self, runner, files):
+        raise NotImplementedError()
 
     def get_path_for_repo_file(self, path, commit=None):
         """Returns a file path for the repository path at commit
@@ -221,10 +222,6 @@ class Vc(object):
         """
         pass
 
-    def get_patch_files(self, patch):
-        regex = re.compile(self.PATCH_INDEX_RE, re.M)
-        return [f.strip() for f in regex.findall(patch)]
-
     # Determine if a directory is a valid git/svn/hg/cvs/etc repository
     def valid_repo(self):
         return True
@@ -251,6 +248,22 @@ class Vc(object):
     def _get_dirsandfiles(self, directory, dirs, files):
         raise NotImplementedError()
 
+    def get_entry(self, path):
+        """Return the entry associated with the given path in this VC
+
+        If the given path does not correspond to any entry in the VC, this
+        method returns return None.
+        """
+        vc_files = [
+            x for x in
+            self.lookup_files(
+                [], [(os.path.basename(path), path)])[1]
+            if x.path == path
+        ]
+        if not vc_files:
+            return None
+        return vc_files[0]
+
 
 class CachedVc(Vc):
 
