@@ -38,9 +38,12 @@ class Vc(_vc.CachedVc):
     CMDARGS = ["--no-aliases", "--no-plugins"]
     NAME = "Bazaar"
     VC_DIR = ".bzr"
-    PATCH_INDEX_RE = "^=== modified file '(.*)'.*$"
     CONFLICT_RE = "conflict in (.*)$"
 
+    commit_statuses = (
+        _vc.STATE_MODIFIED, _vc.STATE_NEW, _vc.STATE_REMOVED
+    )
+
     conflict_map = {
         _vc.CONFLICT_BASE: '.BASE',
         _vc.CONFLICT_OTHER: '.OTHER',
@@ -50,44 +53,63 @@ class Vc(_vc.CachedVc):
 
     # We use None here to indicate flags that we don't deal with or care about
     state_1_map = {
-        " ": None,               # First status column empty
-        "+": None,               # File versioned
-        "-": None,               # File unversioned
-        "R": None,               # File renamed
-        "?": _vc.STATE_NONE,     # File unknown
-        "X": None,               # File nonexistent (and unknown to bzr)
-        "C": _vc.STATE_CONFLICT, # File has conflicts
-        "P": None,               # Entry for a pending merge (not a file)
+        " ": None,                # First status column empty
+        "+": None,                # File versioned
+        "-": None,                # File unversioned
+        "R": None,                # File renamed
+        "?": _vc.STATE_NONE,      # File unknown
+        "X": None,                # File nonexistent (and unknown to bzr)
+        "C": _vc.STATE_CONFLICT,  # File has conflicts
+        "P": None,                # Entry for a pending merge (not a file)
     }
 
     state_2_map = {
-        " ": _vc.STATE_NORMAL,   # Second status column empty
-        "N": _vc.STATE_NEW,      # File created
-        "D": _vc.STATE_REMOVED,  # File deleted
-        "K": None,               # File kind changed
-        "M": _vc.STATE_MODIFIED, # File modified
+        " ": _vc.STATE_NORMAL,    # Second status column empty
+        "N": _vc.STATE_NEW,       # File created
+        "D": _vc.STATE_REMOVED,   # File deleted
+        "K": None,                # File kind changed
+        "M": _vc.STATE_MODIFIED,  # File modified
     }
-    
+
     valid_status_re = r'[%s][%s][\*\s]\s*' % (''.join(state_1_map.keys()),
                                               ''.join(state_2_map.keys()))
 
     def commit_command(self, message):
         return [self.CMD] + self.CMDARGS + ["commit", "-m", message]
-    def diff_command(self):
-        return [self.CMD] + self.CMDARGS + ["diff"]
-    def update_command(self):
-        return [self.CMD] + self.CMDARGS + ["pull"]
+
     def add_command(self):
         return [self.CMD] + self.CMDARGS + ["add"]
-    def remove_command(self, force=0):
-        return [self.CMD] + self.CMDARGS + ["rm"]
-    def revert_command(self):
-        return [self.CMD] + self.CMDARGS + ["revert"]
-    def resolved_command(self):
-        return [self.CMD] + self.CMDARGS + ["resolve"]
+
+    def revert(self, runner, files):
+        runner(
+            [self.CMD] + self.CMDARGS + ["revert"] + files, [], refresh=True,
+            working_dir=self.root)
+
+    def push(self, runner):
+        runner(
+            [self.CMD] + self.CMDARGS + ["push"], [], refresh=True,
+            working_dir=self.root)
+
+    def update(self, runner, files):
+        # TODO: Handle checkouts/bound branches by calling
+        # update instead of pull. For now we've replicated existing
+        # functionality, as update will not work for unbound branches.
+        runner(
+            [self.CMD] + self.CMDARGS + ["pull"], [], refresh=True,
+            working_dir=self.root)
+
+    def resolve(self, runner, files):
+        runner(
+            [self.CMD] + self.CMDARGS + ["resolve"] + files, [], refresh=True,
+            working_dir=self.root)
+
+    def remove(self, runner, files):
+        runner(
+            [self.CMD] + self.CMDARGS + ["rm"] + files, [], refresh=True,
+            working_dir=self.root)
 
     def valid_repo(self):
-        if _vc.call([self.CMD, "info"], cwd=self.root):
+        if _vc.call([self.CMD, "root"], cwd=self.root):
             return False
         else:
             return True
@@ -95,8 +117,21 @@ class Vc(_vc.CachedVc):
     def get_working_directory(self, workdir):
         return self.root
 
+    def get_files_to_commit(self, paths):
+        files = []
+        for p in paths:
+            if os.path.isdir(p):
+                entries = self._lookup_tree_cache(p)
+                names = [
+                    x for x, y in entries.items() if y in self.commit_statuses]
+                files.extend(names)
+            else:
+                files.append(os.path.relpath(p, self.root))
+        return sorted(list(set(files)))
+
     def _lookup_tree_cache(self, rootdir):
-        branch_root = _vc.popen([self.CMD] + self.CMDARGS + ["root", rootdir]).read().rstrip('\n')
+        branch_root = _vc.popen(
+            [self.CMD] + self.CMDARGS + ["root", rootdir]).read().rstrip('\n')
         while 1:
             try:
                 proc = _vc.popen([self.CMD] + self.CMDARGS +
@@ -106,6 +141,7 @@ class Vc(_vc.CachedVc):
             except OSError as e:
                 if e.errno != errno.EAGAIN:
                     raise
+
         tree_state = {}
         for entry in entries:
             state_string, name = entry[:3], entry[4:].strip()
@@ -143,16 +179,14 @@ class Vc(_vc.CachedVc):
             else:
                 retfiles.append(_vc.File(path, name, state))
             bzrfiles[name] = 1
-        for f,path in files:
+        for f, path in files:
             if f not in bzrfiles:
-                #state = ignore_re.match(f) is None and _vc.STATE_NONE or _vc.STATE_IGNORED
                 state = _vc.STATE_NORMAL
                 retfiles.append(_vc.File(path, f, state))
-        for d,path in dirs:
+        for d, path in dirs:
             if d not in bzrfiles:
-                #state = ignore_re.match(f) is None and _vc.STATE_NONE or _vc.STATE_IGNORED
                 state = _vc.STATE_NORMAL
-                retdirs.append( _vc.Dir(path, d, state) )
+                retdirs.append(_vc.Dir(path, d, state))
         return retdirs, retfiles
 
     def get_path_for_repo_file(self, path, commit=None):
@@ -183,3 +217,30 @@ class Vc(_vc.CachedVc):
 
         # bzr paths are all temporary files
         return "%s%s" % (path, self.conflict_map[conflict]), False
+
+    # Sensitivity button mappings.
+    def update_actions_for_paths(self, path_states, actions):
+        states = path_states.values()
+
+        actions["VcCompare"] = bool(path_states)
+        # TODO: We can't disable this for NORMAL, because folders don't
+        # inherit any state from their children, but committing a folder with
+        # modified children is expected behaviour.
+        actions["VcCommit"] = all(s not in (
+            _vc.STATE_NONE, _vc.STATE_IGNORED) for s in states)
+
+        actions["VcUpdate"] = True
+        # TODO: We can't do this; this shells out for each selection change...
+        # actions["VcPush"] = bool(self.get_commits_to_push())
+        actions["VcPush"] = True
+
+        actions["VcAdd"] = all(s not in (
+            _vc.STATE_NORMAL, _vc.STATE_REMOVED) for s in states)
+        actions["VcResolved"] = all(s == _vc.STATE_CONFLICT for s in states)
+        actions["VcRemove"] = (all(s not in (
+            _vc.STATE_NONE, _vc.STATE_IGNORED,
+            _vc.STATE_REMOVED) for s in states) and
+            self.root not in path_states.keys())
+        actions["VcRevert"] = all(s not in (
+            _vc.STATE_NONE, _vc.STATE_NORMAL,
+            _vc.STATE_IGNORED) for s in states)
