@@ -21,8 +21,12 @@
 #OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 #SOFTWARE.
 
-import os
 import errno
+import os
+import shutil
+import subprocess
+import tempfile
+
 from . import _vc
 
 
@@ -31,8 +35,6 @@ class Vc(_vc.CachedVc):
     CMD = "darcs"
     NAME = "Darcs"
     VC_DIR = "_darcs"
-    PATCH_STRIP_NUM = 1
-    PATCH_INDEX_RE = "--- old.+?/(.+?)\\t+.*[0-9]{4}$"
     state_map = {
         "a": _vc.STATE_NONE,
         "A": _vc.STATE_NEW,
@@ -48,10 +50,6 @@ class Vc(_vc.CachedVc):
                 "-a",
                 "-m", message]
 
-    def diff_command(self):
-        return [self.CMD, "diff", "-u",
-                "--repodir=%s" % self.root]
-
     def update_command(self):
         # This will not work while passing the files parameter after it
         # This hack allows you to update in the root directory
@@ -80,6 +78,27 @@ class Vc(_vc.CachedVc):
     def get_working_directory(self, workdir):
         return self.root
 
+    def get_path_for_repo_file(self, path, commit=None):
+        if commit is not None:
+            raise NotImplementedError()
+
+        if not path.startswith(self.root + os.path.sep):
+            raise _vc.InvalidVCPath(self, path, "Path not in repository")
+        path = path[len(self.root) + 1:]
+
+        process = subprocess.Popen([self.CMD, "show", "contents",
+                                    "--repodir=" + self.root, path],
+                                   cwd=self.root, stdout=subprocess.PIPE,
+                                   stderr=subprocess.PIPE)
+        vc_file = process.stdout
+
+        # Error handling here involves doing nothing; in most cases, the only
+        # sane response is to return an empty temp file.
+
+        with tempfile.NamedTemporaryFile(prefix='meld-tmp', delete=False) as f:
+            shutil.copyfileobj(vc_file, f)
+        return f.name
+
     def _get_dirsandfiles(self, directory, dirs, files):
         whatsnew = self._get_tree_cache(directory)
         retfiles, retdirs = (self._get_statuses(whatsnew, files, _vc.File),
