@@ -1,28 +1,31 @@
-### Copyright (C) 2002-2005 Stephen Kennedy <stevek@gnome.org>
+# Copyright (C) 2002-2005 Stephen Kennedy <stevek@gnome.org>
 
-### Redistribution and use in source and binary forms, with or without
-### modification, are permitted provided that the following conditions
-### are met:
-###
-### 1. Redistributions of source code must retain the above copyright
-###    notice, this list of conditions and the following disclaimer.
-### 2. Redistributions in binary form must reproduce the above copyright
-###    notice, this list of conditions and the following disclaimer in the
-###    documentation and/or other materials provided with the distribution.
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+#
+# 1. Redistributions of source code must retain the above copyright
+#    notice, this list of conditions and the following disclaimer.
+# 2. Redistributions in binary form must reproduce the above copyright
+#    notice, this list of conditions and the following disclaimer in the
+#    documentation and/or other materials provided with the distribution.
 
-### THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-### IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-### OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-### IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-### INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-### NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-### DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-### THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-### (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-### THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 import errno
 import os
+import shutil
+import subprocess
+import tempfile
 
 from . import _vc
 
@@ -32,10 +35,7 @@ class Vc(_vc.CachedVc):
     CMD = "hg"
     NAME = "Mercurial"
     VC_DIR = ".hg"
-    PATCH_STRIP_NUM = 1
-    # Mercurial diffs can be run in "git" mode
-    PATCH_INDEX_RE = "^diff (?:-r \w+ |--git a/.* b/)(.*)$"
-    DIFF_GIT_MODE = False
+
     state_map = {
         "?": _vc.STATE_NONE,
         "A": _vc.STATE_NEW,
@@ -47,38 +47,55 @@ class Vc(_vc.CachedVc):
     }
 
     def commit_command(self, message):
-        return [self.CMD,"commit","-m",message]
-    def diff_command(self):
-        ret = [self.CMD,"diff"]
-        if self.DIFF_GIT_MODE:
-            ret.append("--git")
-        return ret
+        return [self.CMD, "commit", "-m", message]
+
     def update_command(self):
-        return [self.CMD,"update"]
+        return [self.CMD, "update"]
+
     def add_command(self):
-        return [self.CMD,"add"]
+        return [self.CMD, "add"]
+
     def remove_command(self, force=0):
-        return [self.CMD,"rm"]
+        return [self.CMD, "rm"]
+
     def revert_command(self):
-        return [self.CMD,"revert"]
+        return [self.CMD, "revert"]
+
     def valid_repo(self):
         if _vc.call([self.CMD, "root"], cwd=self.root):
             return False
         else:
             return True
+
     def get_working_directory(self, workdir):
         if workdir.startswith("/"):
             return self.root
         else:
             return ''
 
+    def get_path_for_repo_file(self, path, commit=None):
+        if commit is not None:
+            raise NotImplementedError()
+
+        if not path.startswith(self.root + os.path.sep):
+            raise _vc.InvalidVCPath(self, path, "Path not in repository")
+        path = path[len(self.root) + 1:]
+
+        process = subprocess.Popen([self.CMD, "cat", path], cwd=self.root,
+                                   stdout=subprocess.PIPE,
+                                   stderr=subprocess.PIPE)
+
+        with tempfile.NamedTemporaryFile(prefix='meld-tmp', delete=False) as f:
+            shutil.copyfileobj(process.stdout, f)
+        return f.name
+
     def _update_tree_state_cache(self, path, tree_state):
         """ Update the state of the file(s) at tree_state['path'] """
         while 1:
             try:
                 # Get the status of modified files
                 proc = _vc.popen([self.CMD, "status", '-A', path],
-                    cwd=self.location)
+                                 cwd=self.location)
                 entries = proc.read().split("\n")[:-1]
 
                 # The following command removes duplicate file entries.
