@@ -1,38 +1,41 @@
-### Copyright (C) 2002-2005 Stephen Kennedy <stevek@gnome.org>
-### Copyright (C) 2005 Daniel Thompson <daniel@redfelineninja.org.uk>
+# Copyright (C) 2002-2005 Stephen Kennedy <stevek@gnome.org>
+# Copyright (C) 2005 Daniel Thompson <daniel@redfelineninja.org.uk>
 
-### Redistribution and use in source and binary forms, with or without
-### modification, are permitted provided that the following conditions
-### are met:
-###
-### 1. Redistributions of source code must retain the above copyright
-###    notice, this list of conditions and the following disclaimer.
-### 2. Redistributions in binary form must reproduce the above copyright
-###    notice, this list of conditions and the following disclaimer in the
-###    documentation and/or other materials provided with the distribution.
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+#
+# 1. Redistributions of source code must retain the above copyright
+#    notice, this list of conditions and the following disclaimer.
+# 2. Redistributions in binary form must reproduce the above copyright
+#    notice, this list of conditions and the following disclaimer in the
+#    documentation and/or other materials provided with the distribution.
 
-### THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-### IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-### OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-### IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-### INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-### NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-### DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-### THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-### (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-### THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 import errno
 import logging
 import os
+import shutil
+import subprocess
+import tempfile
 
 from . import _vc
 
 
 class Vc(_vc.CachedVc):
+    CMD = "mtn"
     NAME = "Monotone"
-    VC_METADATA = ['MT', '_MTN']
-    PATCH_INDEX_RE = "^[+]{3,3} ([^  ]*)\t[0-9a-f]{40,40}$"
+    VC_DIR = "_MTN"
 
     state_map_6 = {
         'added known rename_source'         : _vc.STATE_NEW,
@@ -112,49 +115,54 @@ class Vc(_vc.CachedVc):
         'RRM' : _vc.STATE_MISSING,  # rename source and target and target missing
     }
 
-    def __init__(self, location):
-        self.interface_version = 0.0
-        self.choose_monotone_version()
-        super(Vc, self).__init__(os.path.normpath(location))
-
-    def choose_monotone_version(self):
-        log = logging.getLogger(__name__)
-
-        try:
-            # for monotone >= 0.26
-            self.VC_DIR = "_MTN"
-            self.CMD = "mtn"
-            self.interface_version = float(_vc.popen([self.CMD, "automate", "interface_version"]).read())
-            if self.interface_version > 9.0:
-                log.error("Unsupported monotone interface version; please "
-                          "report any problems to the Meld mailing list.")
-        except (ValueError, OSError):
-            # for monotone <= 0.25
-            self.VC_DIR = "MT"
-            self.CMD = "monotone"
-
     def commit_command(self, message):
-        return [self.CMD,"commit","-m",message]
-    def diff_command(self):
-        return [self.CMD,"diff"]
+        return [self.CMD, "commit", "-m", message]
+
     def update_command(self):
-        return [self.CMD,"update"]
+        return [self.CMD, "update"]
+
     def add_command(self):
-        return [self.CMD,"add"]
+        return [self.CMD, "add"]
+
     def remove_command(self, force=0):
-        return [self.CMD,"drop"]
+        return [self.CMD, "drop"]
+
     def revert_command(self):
-        return [self.CMD,"revert"]
+        return [self.CMD, "revert"]
+
     def resolved_command(self):
-        return [self.CMD,"resolved"]
+        return [self.CMD, "resolved"]
+
     def valid_repo(self):
         if _vc.call([self.CMD, "list", "tags"], cwd=self.root):
             return False
         else:
             return True
+
     def get_working_directory(self, workdir):
         return self.root
 
+    def get_path_for_repo_file(self, path, commit=None):
+        if commit is None:
+            commit = ""
+
+        if not path.startswith(self.root + os.path.sep):
+            raise _vc.InvalidVCPath(self, path, "Path not in repository")
+        path = path[len(self.root) + 1:]
+
+        command = [self.CMD, "cat", path]
+        if commit:
+            command.extend(["--revision", commit])
+
+        process = subprocess.Popen(command,
+                                   cwd=self.root, stdout=subprocess.PIPE,
+                                   stderr=subprocess.PIPE)
+        vc_file = process.stdout
+
+        with tempfile.NamedTemporaryFile(prefix='meld-tmp', delete=False) as f:
+            shutil.copyfileobj(vc_file, f)
+        return f.name
+
     def _lookup_tree_cache(self, rootdir):
         log = logging.getLogger(__name__)
 
@@ -167,71 +175,52 @@ class Vc(_vc.CachedVc):
                 if e.errno != errno.EAGAIN:
                     raise
 
-        if self.interface_version >= 6.0:
-            # this version of monotone uses the new inventory format
+        # This handles interface versions from 6.0 to 9.0
+        interface_version = float(
+            _vc.popen([self.CMD, "automate", "interface_version"]).read())
+        if interface_version < 6.0 or interface_version > 9.0:
+            log.error("Unsupported monotone interface version; please "
+                      "report any problems to the Meld mailing list.")
 
-            # terminate the final stanza. basic io stanzas are blank line seperated with no
-            # blank line at the beginning or end (and we need to loop below to act upon the
-            # final stanza
-            entries.append('')
-
-            tree_state = {}
-            stanza = {}
-            for entry in entries:
-                if entry != '':
-                    # this is part of a stanza and is structured '   word "value1" "value2"',
-                    # we convert this into a dictionary of lists: stanza['word'] = [ 'value1', 'value2' ]
-                    entry = entry.strip().split()
-                    tag = entry[0]
-                    values = [i.strip('"') for i in entry[1:]]
-                    stanza[tag] = values
-                else:
-                    # extract the filename (and append / if is is a directory)
-                    fname = stanza['path'][0]
-                    if stanza['fs_type'][0] == 'directory':
-                        fname = fname + '/'
-
-                    # sort the list and reduce it from a list to a space seperated string.
-                    mstate = stanza['status']
-                    mstate.sort()
-                    mstate = ' '.join(mstate)
-
-                    if mstate in self.state_map_6:
-                        if 'changes' in stanza:
-                            state = _vc.STATE_MODIFIED
-                        else:
-                            state = self.state_map_6[mstate]
-                            if state == _vc.STATE_ERROR:
-                                log.warning("Invalid state '%s' reported for "
-                                            "%s", mstate, fname)
-                    else:
-                        state = _vc.STATE_ERROR
-                        log.warning("Invalid state '%s' reported for %s "
-                                    "(version skew?)", mstate, fname)
-
-                    # insert the file into the summarized inventory
-                    tree_state[os.path.join(self.root, fname)] = state
-
-                    # clear the stanza ready for next iteration
-                    stanza = {}
-
-            return tree_state
+        # Terminate the final stanza, since basic stanzas are blank line
+        # seperated with no blank line at the beginning or end.
+        entries.append('')
 
         tree_state = {}
+        stanza = {}
         for entry in entries:
-            mstate = entry[0:3]
-            fname = entry[8:]
-
-            if mstate in self.state_map_old:
-                state = self.state_map_old[mstate]
-                if state == _vc.STATE_ERROR:
-                    log.warning("Invalid state '%s' reported", mstate)
+            if entry != '':
+                # This is part of a stanza and is structured:
+                #     '   word "value1" "value2"'
+                # We convert this into a dictionary of lists:
+                #     stanza['word'] = [ 'value1', 'value2' ]
+                entry = entry.strip().split()
+                tag = entry[0]
+                values = [i.strip('"') for i in entry[1:]]
+                stanza[tag] = values
             else:
-                state = _vc.STATE_ERROR
-                log.warning("Invalid state '%s' reported (version skew?)",
-                            mstate)
+                fname = stanza['path'][0]
+                if stanza['fs_type'][0] == 'directory':
+                    fname = fname + '/'
 
-            tree_state[os.path.join(self.root, fname)] = state
+                mstate = ' '.join(sorted(stanza['status']))
+                if mstate in self.state_map_6:
+                    if 'changes' in stanza:
+                        state = _vc.STATE_MODIFIED
+                    else:
+                        state = self.state_map_6[mstate]
+                        if state == _vc.STATE_ERROR:
+                            log.warning("Invalid state '%s' reported for "
+                                        "%s", mstate, fname)
+                else:
+                    state = _vc.STATE_ERROR
+                    log.warning("Invalid state '%s' reported for %s "
+                                "(version skew?)", mstate, fname)
+
+                tree_state[os.path.join(self.root, fname)] = state
+
+                # Clear the stanza ready for next iteration
+                stanza = {}
 
         return tree_state
 
@@ -255,27 +244,27 @@ class Vc(_vc.CachedVc):
             else:
                 retfiles.append(_vc.File(path, name, state))
             vcfiles[name] = 1
-        for f,path in files:
+        for f, path in files:
             if f not in vcfiles:
                 # if the ignore MT filter is not enabled these will crop up
-                ignorelist = [ 'format', 'log', 'options', 'revision', 'work', 'debug', 'inodeprints' ]
+                ignorelist = ['format', 'log', 'options', 'revision', 'work',
+                              'debug', 'inodeprints']
 
                 if f not in ignorelist:
                     log.warning("'%s' was not listed", f)
 
-                # if it ain't listed by the inventory it's not under version
-                # control
+                # If not in the inventory it's not under version control.
                 state = _vc.STATE_NONE
                 retfiles.append(_vc.File(path, f, state))
-        for d,path in dirs:
+        for d, path in dirs:
             if d not in vcfiles:
                 # if the ignore MT filter is not enabled these will crop up
-                ignorelist = [ 'MT' ]
+                ignorelist = ['MT']
                 if d in ignorelist:
                     state = _vc.STATE_NONE
                 else:
                     # monotone does not version (or inventory) directories
                     # so these are always normal
                     state = _vc.STATE_NORMAL
-                retdirs.append( _vc.Dir(path, d, state) )
+                retdirs.append(_vc.Dir(path, d, state))
         return retdirs, retfiles
