@@ -160,7 +160,7 @@ class VcView(melddoc.MeldDoc, gnomeglade.Component):
             ("VcCompare", gtk.STOCK_DIALOG_INFO, _("_Compare"), None,
                 _("Compare selected files"),
                 self.on_button_diff_clicked),
-            ("VcCommit", "vc-commit-24", _("Co_mmit..."), None,
+            ("VcCommit", "vc-commit-24", _("Co_mmit..."), "<Ctrl>M",
                 _("Commit changes to version control"),
                 self.on_button_commit_clicked),
             ("VcUpdate", "vc-update-24", _("_Update"), None,
@@ -435,6 +435,7 @@ class VcView(melddoc.MeldDoc, gnomeglade.Component):
     def _search_recursively_iter(self, iterstart):
         rootname = self.model.value_path(iterstart, 0)
         prefixlen = len(self.location) + 1
+        symlinks_followed = set()
         todo = [(self.model.get_path(iterstart), rootname)]
 
         flattened = self.actiongroup.get_action("VcFlatten").get_active()
@@ -455,9 +456,24 @@ class VcView(melddoc.MeldDoc, gnomeglade.Component):
             entries = self.vc.listdir(path)
             entries = [e for e in entries if any(f(e) for f in filters)]
             for e in entries:
-                if e.isdir and flattened:
-                    todo.append(((0,), e.path))
-                    continue
+                if e.isdir:
+                    try:
+                        st = os.lstat(e.path)
+                    # Covers certain unreadable symlink cases; see bgo#585895
+                    except OSError as err:
+                        error_string = "%s: %s" % (e.path, err.strerror)
+                        self.model.add_error(it, error_string, 0)
+                        continue
+
+                    if stat.S_ISLNK(st.st_mode):
+                        key = (st.st_dev, st.st_ino)
+                        if key in symlinks_followed:
+                            continue
+                        symlinks_followed.add(key)
+
+                    if flattened:
+                        todo.append(((0,), e.path))
+                        continue
 
                 child = self.model.add_entries(it, [e.path])
                 self._update_item_state(child, e, path[prefixlen:])
@@ -635,6 +651,11 @@ class VcView(melddoc.MeldDoc, gnomeglade.Component):
             misc.run_dialog("Error running command.\n'%s'\n\nThe error was:\n%s" % ( misc.shelljoin(command), e),
                 parent=self, messagetype=gtk.MESSAGE_ERROR)
         self.consolestream.output("\n")
+
+        returncode = next(readiter)
+        if returncode:
+            self.set_console_view_visible(True)
+
         if refresh:
             self.refresh_partial(workdir)
         yield workdir, r
@@ -806,6 +827,12 @@ class VcView(melddoc.MeldDoc, gnomeglade.Component):
 
     def on_console_view_toggle(self, box, event=None):
         if box == self.console_hide_box:
+            self.set_console_view_visible(False)
+        else:
+            self.set_console_view_visible(True)
+
+    def set_console_view_visible(self, visible):
+        if not visible:
             self.prefs.vc_console_visible = 0
             self.console_hbox.hide()
             self.console_show_box.show()
